@@ -21,12 +21,9 @@
 #include "Util.hpp"
 
 #include <core/exceptions.hpp>
+#include <util/file.hpp>
 #include <util/string.hpp>
 
-using nonstd::nullopt;
-using nonstd::optional;
-using nonstd::string_view;
-
 Args::Args(Args&& other) noexcept : m_args(std::move(other.m_args))
 {
 }
@@ -40,7 +37,7 @@ Args::from_argv(int argc, const char* const* argv)
 }
 
 Args
-Args::from_string(const std::string& command)
+Args::from_string(std::string_view command)
 {
   Args args;
   for (const std::string& word : Util::split_into_strings(command, " \t\r\n")) {
@@ -49,20 +46,18 @@ Args::from_string(const std::string& command)
   return args;
 }
 
-optional<Args>
+std::optional<Args>
 Args::from_atfile(const std::string& filename, AtFileFormat format)
 {
-  std::string argtext;
-  try {
-    argtext = Util::read_text_file(filename);
-  } catch (core::Error&) {
-    return nullopt;
+  const auto argtext = util::read_file<std::string>(filename);
+  if (!argtext) {
+    return std::nullopt;
   }
 
   Args args;
-  auto pos = argtext.c_str();
+  auto pos = argtext->c_str();
   std::string argbuf;
-  argbuf.resize(argtext.length() + 1);
+  argbuf.resize(argtext->length() + 1);
   auto argpos = argbuf.begin();
 
   // Used to track quoting state; if \0 we are not inside quotes. Otherwise
@@ -91,7 +86,7 @@ Args::from_atfile(const std::string& filename, AtFileFormat format)
       if (format == AtFileFormat::msvc) {
         break;
       }
-      // Fall through.
+      [[fallthrough]];
 
     case '"':
       if (quoting != '\0') {
@@ -115,7 +110,7 @@ Args::from_atfile(const std::string& filename, AtFileFormat format)
       if (quoting) {
         break;
       }
-      // Fall through.
+      [[fallthrough]];
 
     case '\0':
       // End of token
@@ -173,7 +168,7 @@ Args::to_string() const
 }
 
 void
-Args::erase_last(string_view arg)
+Args::erase_last(std::string_view arg)
 {
   const auto it = std::find(m_args.rbegin(), m_args.rend(), arg);
   if (it != m_args.rend()) {
@@ -182,7 +177,7 @@ Args::erase_last(string_view arg)
 }
 
 void
-Args::erase_with_prefix(string_view prefix)
+Args::erase_with_prefix(std::string_view prefix)
 {
   m_args.erase(std::remove_if(m_args.begin(),
                               m_args.end(),
